import AccountCircleIcon from '@mui/icons-material/AccountCircle'
import RouterIcon from '@mui/icons-material/Router'
import { Button } from '@mui/material'
import { useAppSelector } from '../../hooks/store'
import { NavLink, Outlet, To } from 'react-router-dom'
import { appPrivateRoutes } from '../../routes'
import { Container } from '../../components/Container'
import { Footer } from '../../components/Footer/Footer'
import ExtensionIcon from '@mui/icons-material/Extension'
import { LoginMethod } from '../../store/auth/types'
import styles from './style.module.scss'
import { ReactNode } from 'react'

const Item = (to: To, icon: ReactNode, label: string) => {
  return (
    <NavLink to={to}>
      {({ isActive }) => (
        <Button
          fullWidth
          sx={{
            transition: 'ease 0.3s',
            justifyContent: 'start',
            gap: '10px',
            background: 'rgba(76,130,163,0)',
            color: '#434343',
            fontWeight: 600,
            opacity: 0.75,
            textTransform: 'none',
            ...(isActive
              ? {
                  background: '#447592',
                  color: 'white'
                }
              : {}),
            '&:hover': {
              opacity: 0.85,
              gap: '15px',
              background: '#5e8eab',
              color: 'white'
            }
          }}
          variant={'text'}
        >
          {icon}
          {label}
        </Button>
      )}
    </NavLink>
  )
}

export const SettingsLayout = () => {
  const { loginMethod } = useAppSelector((state) => state.auth)

  return (
    <>
      <Container>
        <h2 className={styles.title}>Settings</h2>
        <div className={styles.main}>
          <div>
            <aside className={styles.aside}>
              {Item(
                appPrivateRoutes.profileSettings,
                <AccountCircleIcon />,
                'Profile'
              )}
              {Item(appPrivateRoutes.relays, <RouterIcon />, 'Relays')}
              {loginMethod === LoginMethod.nostrLogin &&
                Item(
                  appPrivateRoutes.nostrLogin,
                  <ExtensionIcon />,
                  'Nostr Login'
                )}
            </aside>
          </div>
          <div className={styles.content}>
            <Outlet />
          </div>
        </div>
      </Container>
      <Footer />
    </>
  )
}
