import { State } from '../store/rootReducer'

export const saveState = (state: object) => {
  try {
    const serializedState = JSON.stringify(state)

    localStorage.setItem('state', serializedState)
  } catch (err) {
    console.log(`Error while saving state. Error: `, err)
  }
}

export const loadState = (): State | undefined => {
  try {
    const serializedState = localStorage.getItem('state')

    if (serializedState === null) return undefined

    return JSON.parse(serializedState)
  } catch (err) {
    return undefined
  }
}

export const clearState = () => {
  localStorage.removeItem('state')
}

export const saveAuthToken = (token: string) => {
  localStorage.setItem('authToken', token)
}

export const getAuthToken = () => {
  return localStorage.getItem('authToken')
}

export const clearAuthToken = () => {
  localStorage.removeItem('authToken')
}

export const clear = () => {
  clearAuthToken()
  clearState()
}

export function mergeWithInitialValue<T>(storedValue: T, initialValue: T): T {
  if (
    !Array.isArray(storedValue) &&
    typeof storedValue === 'object' &&
    storedValue !== null
  ) {
    return { ...initialValue, ...storedValue }
  }
  return storedValue
}

export function getLocalStorageItem<T>(key: string, defaultValue: T): string {
  try {
    const data = window.localStorage.getItem(key)
    if (data === null) return JSON.stringify(defaultValue)
    return data
  } catch (err) {
    console.error(`Error while fetching local storage value: `, err)
    return JSON.stringify(defaultValue)
  }
}

export function setLocalStorageItem(key: string, value: string) {
  try {
    window.localStorage.setItem(key, value)
    dispatchLocalStorageEvent(key, value)
  } catch (err) {
    console.error(`Error while saving local storage value: `, err)
  }
}

export function removeLocalStorageItem(key: string) {
  try {
    window.localStorage.removeItem(key)
    dispatchLocalStorageEvent(key, null)
  } catch (err) {
    console.error(`Error while deleting local storage value: `, err)
  }
}

function dispatchLocalStorageEvent(key: string, newValue: string | null) {
  window.dispatchEvent(new StorageEvent('storage', { key, newValue }))
}
